--冒险之旅 主界面
Lua_ExploreTourWindow = class("Lua_ExploreTourWindow", Lua_Window);
function Lua_ExploreTourWindow:ctor()
	self:superCall("ctor");

	self.isFullSizeWin = true;
	self.showBackBtn = true;
	self.layer = MainWinDefine.MAIN_MENU_TOP_LAYER;
	self.windowName = "Lua_ExploreTourWindow";
	self.skinName = "ExploreTourWindow_skin";
	self.showWinBg = true;
	self.winBgPath = "/images/exploreTour/ui_mxzl_bj_001.jpg";

    self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
end

function Lua_ExploreTourWindow:buildPanel(go)
	self:superCall("buildPanel", go);

	self:addLuaEvent("UPDATE_EXPLORER_TOUR_INFO", self, self.updateInfo);
	self:addLuaEvent("UPDATE_EXPLORER_TOUR_SELECT", self, self.updateInfo);
end

function Lua_ExploreTourWindow:buildShowItem()
	self:superCall("buildShowItem");

	local item;
	local posDic = {{-285, 290}, {-172, 260}, {172, 260}, {285, 290}};
	self.rewardArr = Array();
	for k, v in pairs(posDic) do
		item = Lua_ExploreTourRewardItem.new(self.rewardObj);
		item:setLocation(v[1], v[2], 0);
		self.rewardArr:add(item);
	end

	self.btnList = Lua_DragContainer.new(self.upObj, 700, 95, Lua_AxisDefine.Horizontal);
	self.btnList:setLocation(0, -95, 0);

	local arr = DataCenter.taskUtil.exploreTourStageArr;
	for i = 1, arr:getSize() do
		self.btnList:addSubContainer(Lua_ExploreTourBtnItem, arr[i]);
	end
	self.btnList:updateChildPos();

	self.taskList = Lua_DragList.new(self.upObj, 720, 455 + self.adaptHeight, Lua_AxisDefine.Vertical);
	self.taskList:setListCell(Lua_ExploreTourTaskItem, 355, 193, 2);
	self.taskList:setRectPivot(1);
	self.taskList:setSubOffect(5, 0);
    self.taskList:setLocation(0, -143, 0);

    -- Lua_ProxyManager.getProxy("Lua_TaskProxy"):sExploreTourInfo();

    self.artifactBg.clickScale = false;
    self.artifactBg:addClickFuntion(self, self.onGuideBtnClick);
    self.receiveBtn:addClickFuntion(self, self.onReceiveBtnClick);

    self:updateInfo(DataCenter.taskData.curStageId);
end

function Lua_ExploreTourWindow:dispose()
	if self.rewardArr ~= nil then
		self.rewardArr:dispose();
		self.rewardArr = nil;
	end
	if self.btnList ~= nil then
		self.btnList:dispose();
		self.btnList = nil;
	end
	if self.taskList ~= nil then
		self.taskList:dispose();
		self.taskList = nil;
	end
	self:superCall("dispose");
end

function Lua_ExploreTourWindow:onScreenResize()
	self:superCall("onScreenResize");

	self.taskList:setContentRect(720, 455 + self.adaptHeight);
end

function Lua_ExploreTourWindow:updateInfo(stageId)
	DataCenter.taskData.selectIdx = stageId;
	
	self.btnList:setChildData(DataCenter.taskUtil.exploreTourStageArr);

	if self.selectStage == nil then
		self.btnList:moveToIndex(stageId, true);
	end

	self:updateSelect(stageId);
end

function Lua_ExploreTourWindow:updateSelect(stageId)
	self.selectStage = stageId;

	self.artifactObj:SetActive(false);
	self.receiveBtn:setEnable(false);
	self.rewardObj:SetActive(false);
	self.lockObj:SetActive(false);
	self.guideObj:SetActive(false);

	local curStageId = DataCenter.taskData.curStageId;
	local curRewardState = DataCenter.taskData.curRewardState;
	local artifactState = DataCenter.taskData.artifactState;

	--显示神器
	local artifactId = DataCenter.taskUtil:getExploreTourStageInfo(self.selectStage, "unlock_artifact");
	if artifactId ~= nil then
		local artifactVo = Lua_ArtifactVo.new(artifactId);
		self.lockTxt.text = LanUtil.formateStr(310000, artifactVo.name);

		self.artifactObj:SetActive(self.selectStage > curStageId or (self.selectStage == curStageId and artifactState == 0));
	end

	--显示奖励
	if self.selectStage > curStageId or (self.selectStage == curStageId and curRewardState ~= 2) then
		local vo;
		local rewardConfig = DataCenter.taskUtil:getExploreTourStageInfo(self.selectStage, "reward");
		for i = 1, #rewardConfig do
			vo = Lua_ToolVo.createToolVo(rewardConfig[i][1], rewardConfig[i][2]);
			self.rewardArr[i]:setData(vo);
		end
		self.rewardObj:SetActive(true);
	end
	
	if self.selectStage == curStageId then
		if curRewardState == 0 then
			self.tipTxt:setLangValue(310001);
			self.lockObj:SetActive(artifactId ~= nil);
		elseif curRewardState == 1 then
			self.tipTxt.text = "";
			self.receiveBtn:setEnable(true);
			self.lockObj:SetActive(artifactId ~= nil);
		elseif curRewardState == 2 then
			self.tipTxt:setLangValue(310002);
			self.guideObj:SetActive(artifactId ~= nil and artifactState == 0);
		end
	elseif self.selectStage > curStageId then
		self.tipTxt:setLangValue(310003);
		self.lockObj:SetActive(artifactId ~= nil);
	elseif self.selectStage < curStageId then
		self.tipTxt:setLangValue(310002);
	end

	local arr = DataCenter.taskUtil:getExploreTourTaskArr(self.selectStage);
	if arr ~= nil then
		arr:sort("sort", false);
	end
	self.taskList:setArrayData(arr);
end

function Lua_ExploreTourWindow:onReceiveBtnClick(go)
	if self.selectStage == DataCenter.taskData.curStageId and DataCenter.taskData.curRewardState == 1 then
		Lua_ProxyManager.getProxy("Lua_TaskProxy"):sExploreTourReward(0);
	end
end

function Lua_ExploreTourWindow:onGuideBtnClick(go)
	if self.selectStage == DataCenter.taskData.curStageId and DataCenter.taskData.curRewardState == 2 then
		Lua_ProxyManager.getProxy("Lua_TaskProxy"):sUnLockArtifact();
	end
end




-- 检测引导数据
function Lua_ExploreTourWindow:checkWinGuide()
	-- print("checkWinGuide")
    self:superCall("checkWinGuide");
end

-- 引导同步
function Lua_ExploreTourWindow:updateGuide(guideId, info)
	-- print("Lua_ExploreTourWindow2", info, self.selectStage)
    if info == nil or self.selectStage == nil then
        return;
    end

    local operateVal = info.operateVal; -- 操作行为参数
    -- print("操作行为参数operateVal = ", operateVal);
    if operateVal == nil then
        return;
    end

    local selectStage = tonumber(info.selectStage);
    if operateVal == 1 then -- 任务阶段
    	local selectStage = selectStage or 1;
        local item = self.btnList.showDragDataList:getItem(selectStage).cell;
        if item ~= nil then
            if self.selectStage ~= nil and self.selectStage == selectStage then
                DataCenter.guideCommonData.winGuideResult = 1;
            else
                item:checkCellPressInGuide(true, guideId);
            end
            DataCenter.guideCommonData.guideClickObjTarget = item.content;
            DataCenter.guideCommonData.guideSceneId = nil; -- 场景
            Lua_MsgUtil.callFunc("Guide_WinSync_Complete", guideId);
        end
    end
end




--------------------------------------------------





Lua_ExploreTourRewardItem = class("Lua_ExploreTourRewardItem", Lua_DisplayObject);
function Lua_ExploreTourRewardItem:ctor(p)
	self:superCall("ctor", p, "ExploreTourRewardItem_skin");
end

function Lua_ExploreTourRewardItem:buildShowItem()
	self:superCall("buildShowItem");

	self.itemIcon = UICreate.createUIAtlasImage(self.content, "", "", 0, 0, 0, 0);
	self.itemIcon.siblingIndex = 1;

	self.itemBg:addClickFuntion(self, self.onClick);
end

function Lua_ExploreTourRewardItem:dispose()
	if self.itemIcon ~= nil then
		self.itemIcon:dispose();
		self.itemIcon = nil;
	end
	self:superCall("dispose");
end

function Lua_ExploreTourRewardItem:setData(data)
	self._data = data;

	self.itemTxt.text = numberTrans(data.count);
	-- self.itemIcon:setAltas(data.atlas, data.sprite);
	local atlas, sprite = data:getAvatarFromItemTable();
	self.itemIcon:setEnable(atlas ~= nil);
	self.itemIcon:setAltas(atlas, sprite);
	if data.main_type == 2 then
		self.itemIcon:resetSize();
		self.itemIcon:setScale(0.8, 0.8, 0.8);
	else
		self.itemIcon:setScale(1, 1, 1);
		self.itemIcon:resetSize();
	end

	self.itemBg:setAltas("exploreTour_atlas", "ui_mxzl_itembg_00" .. data.color);
end

function Lua_ExploreTourRewardItem:onClick(go)
	if self._data ~= nil then
		DataCenter.packUtil:showItemInfo(self._data);
	end
end





--------------------------------------------------





Lua_ExploreTourBtnItem = class("Lua_ExploreTourBtnItem", Lua_DragContainerItem);
function Lua_ExploreTourBtnItem:ctor(p)
    self:superCall("ctor", p, "ExploreTourBtnItem_skin");
end

function Lua_ExploreTourBtnItem:buildShowItem()
    self:superCall("buildShowItem");

    self.redPointIcon = Lua_RedPointIcon.new(self.obj);
    self.redPointIcon:createRedPointEff();
    self.redPointIcon:updateRedPointShow(false);
    self.redPointIcon:setLocation(-26, 26, 0);
end

function Lua_ExploreTourBtnItem:dispose()
	if self.redPointIcon ~= nil then
		self.redPointIcon:dispose();
		self.redPointIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExploreTourBtnItem:setData(data)
	self.data = data;

	self.btnTxt.text = self.data.title;
	self.titleTxt.text = self.data.content;

	self.isSelect = DataCenter.taskData.selectIdx == data.id;
	if self.isSelect then
		self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("4a1e0d");
		self.btnIcon:setAltas("exploreTour_atlas", "ui_mxzl_label_03");
		self.progressBar:SetDimensions(133 + 260 - 208, 10);
		self.progressBar:setLocation(65, 0, 0);
		LuaUtil.setObjPos(self.obj, -25, 0, 0);
	else
		self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("2b2c4d");
		self.btnIcon:setAltas("exploreTour_atlas", "ui_mxzl_label_02");
		self.progressBar:SetDimensions(133, 10);
		self.progressBar:setLocation(39, 0, 0);
		LuaUtil.setObjPos(self.obj, 0, 0, 0);
	end
	self.btnIcon:resetSize();
	self.titleObj:SetActive(self.isSelect);

	local isShowBar = self.data.id ~= DataCenter.taskUtil:getConstConfig("max_stage", 1);
	if isShowBar then
		local stageProgress = DataCenter.taskData:getStagePrograss(self.data.id);
		self.progressBar:setMaxValue(stageProgress[2]);
		self.progressBar:setValue(stageProgress[1]);
	end
	self.progressBar:setEnable(isShowBar);

	local taskData = DataCenter.taskData;
	if self.data.id == taskData.curStageId then
		local redDotState = DataCenter.redPointData:getRedPointStateById(Lua_RedPointList.ExploreTour);
		self.redPointIcon:updateRedPointShow(redDotState);
	else
		self.redPointIcon:updateRedPointShow(false);
	end
end

function Lua_ExploreTourBtnItem:onPressClick()
	if self.isSelect == false then
		Lua_MsgUtil.callFunc("UPDATE_EXPLORER_TOUR_SELECT", self.data.id);

		self:checkGuideCellState();
	end
end

function Lua_ExploreTourBtnItem:getWidth()
    if self.isSelect then
		return 260;
	else
		return 208;
	end
end

function Lua_ExploreTourBtnItem:getHeight()
	return 95;
end

-- 引导用
function Lua_ExploreTourBtnItem:checkCellPressInGuide(bGuide, guideId)
    self.bPressCell = bGuide;
    self.guideId = guideId;
end

-- 引导用
function Lua_ExploreTourBtnItem:checkGuideCellState()
    if self.bPressCell and self.guideId then
        DataCenter.guideCommonData.winGuideResult = 1;
        Lua_MsgUtil.callFunc("Guide_WinSync_Complete", self.guideId);
        self:checkCellPressInGuide(nil, nil);
    end
end




--------------------------------------------------





Lua_ExploreTourTaskItem = class("Lua_ExploreTourTaskItem", Lua_ListCell);
function Lua_ExploreTourTaskItem:ctor(p)
	self:superCall("ctor", p, "ExploreTourTaskItem_skin");
end

function Lua_ExploreTourTaskItem:buildShowItem()
    self:superCall("buildShowItem");
    self.titleTxt.horizontalOverflowValue = 1;

    self.redPointIcon = Lua_RedPointIcon.new(self.content);
    self.redPointIcon:createRedPointEff();
    self.redPointIcon:updateRedPointShow(false);
    self.redPointIcon:setLocation(165, -47, 0);

    self.btnBg.clickScale = false;
    self.btnBg:addClickFuntion(self, self.onShowBtnClick);
end

function Lua_ExploreTourTaskItem:dispose()
	if self.redPointIcon ~= nil then
		self.redPointIcon:dispose();
		self.redPointIcon = nil;
	end
	self.data = nil;
	self:superCall("dispose");
end

function Lua_ExploreTourTaskItem:setData(data)
	self.data = data;

	self.titleTxt.text = data.title;
	self.detailTxt.text = data.description;
	self.itemTxt.text = data.rewardVo.count;

	self.progressObj:SetActive(false);
	self.itemIcon:setAltas("exploreTour_atlas", "ui_mxzl_icon_003");

	local curStageId = DataCenter.taskData.curStageId;
	if data.stage > curStageId then
		self.itemIcon:setAltas("exploreTour_atlas", "ui_mxzl_icon_002");

		self.itemIcon:setEnable(true);
		self.itemTxt:setEnable(false);
		self.btnBg:setEnable(false);
		self.btnTxt:setEnable(false);
		self.maskIcon:setEnable(false);
		self:setBgShow(2);
	elseif data.stage < curStageId then
		self.itemIcon:setEnable(false);
		self.itemTxt:setEnable(false);
		self.btnBg:setEnable(false);
		self.btnTxt:setEnable(false);
		self.maskIcon:setEnable(true);
		self:setBgShow(4);
	else
		if data.rewardState == 0 then
			self.btnBg:setAltas("exploreTour_atlas", "ui_mxzl_button_002_n");
			self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("282a45");
			self.btnTxt:setLangValue(310004);
			self.condTxt.text = "(<color=#3ded4e>" .. numberTrans(data.taskProgress) .. "</color>/" .. numberTrans(data.process) .. ")";
			self:setBgShow(3);
		elseif data.rewardState == 1 then
			self.btnBg:setAltas("exploreTour_atlas", "ui_mxzl_button_003_n");
			self.btnTxt.colorStr = Lua_ColorDefine.transColorStr("9d511b");
			self.btnTxt:setLangValue(310005);
			self.condTxt.text = "<color=#3ded4e>(" .. numberTrans(data.taskProgress) .. "/" .. numberTrans(data.process) .. ")</color>";
			self:setBgShow(1);
		else
			self:setBgShow(4);
		end

		self.progressBar:setMaxValue(data.process);
		self.progressBar:setValue(data.taskProgress);

		self.progressObj:SetActive(data.rewardState ~= 2);
		self.itemIcon:setEnable(data.rewardState ~= 2);
		self.itemTxt:setEnable(data.rewardState ~= 2);
		self.btnBg:setEnable(data.rewardState ~= 2);
		self.btnTxt:setEnable(data.rewardState ~= 2);
		self.maskIcon:setEnable(data.rewardState == 2);
	end
	self.redPointIcon:updateRedPointShow(data.stage == curStageId and data.rewardState == 1);
end

function Lua_ExploreTourTaskItem:setBgShow(index)
	self.bg:setAltas("exploreTour_atlas", "ui_mxzl_window_00" .. index);
	self.bg:resetSize();

	if index == 1 then
		self.bg:setLocation(3, 0, 0);
	else
		self.bg:setLocation(0, 0, 0);
	end
end

function Lua_ExploreTourTaskItem:onShowBtnClick()
	if self.data == nil then return end

	if self.data.stage == DataCenter.taskData.curStageId then
		if self.data.rewardState == 0 then
			DataCenter.funcPathUtil:gotoFunction(self.data.func_path_id, true);
		elseif self.data.rewardState == 1 then
			Lua_ProxyManager.getProxy("Lua_TaskProxy"):sExploreTourReward(self.data.id);
		end
	end
end